=== modified file 'drizzled/cursor.cc'
--- drizzled/cursor.cc	2011-08-08 12:51:19 +0000
+++ drizzled/cursor.cc	2011-08-05 10:29:23 +0000
@@ -589,12 +589,27 @@
   next_insert_id= 0;
 }
 
-void Cursor::drop_table()
+void Cursor::drop_table(const char *)
 {
   close();
 }
 
-int Cursor::ha_check(Session*)
+
+/**
+  Performs checks upon the table.
+
+  @param session                thread doing CHECK Table operation
+
+  @retval
+    HA_ADMIN_OK               Successful upgrade
+  @retval
+    HA_ADMIN_NEEDS_UPGRADE    Table has structures requiring upgrade
+  @retval
+    HA_ADMIN_NEEDS_ALTER      Table has structures requiring ALTER Table
+  @retval
+    HA_ADMIN_NOT_IMPLEMENTED
+*/
+int Cursor::ha_check(Session *)
 {
   return HA_ADMIN_OK;
 }
@@ -728,9 +743,11 @@
   @sa Cursor::discard_or_import_tablespace()
 */
 
-int Cursor::ha_discard_or_import_tablespace(bool discard)
+int
+Cursor::ha_discard_or_import_tablespace(bool discard)
 {
   setTransactionReadWrite();
+
   return discard_or_import_tablespace(discard);
 }
 
@@ -740,58 +757,60 @@
   @sa Cursor::drop_table()
 */
 
-void Cursor::closeMarkForDelete()
+void
+Cursor::closeMarkForDelete(const char *name)
 {
   setTransactionReadWrite();
-  return drop_table();
+
+  return drop_table(name);
 }
 
 int Cursor::index_next_same(unsigned char *buf, const unsigned char *key, uint32_t keylen)
 {
-  int error= index_next(buf);
-  if (error)
-    return error;
-
-  ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
-  unsigned char *save_record_0= NULL;
-  KeyInfo *key_info= NULL;
-  KeyPartInfo *key_part;
-  KeyPartInfo *key_part_end= NULL;
-
-  /*
-  key_cmp_if_same() compares table->getInsertRecord() against 'key'.
-  In parts it uses table->getInsertRecord() directly, in parts it uses
-  field objects with their local pointers into table->getInsertRecord().
-  If 'buf' is distinct from table->getInsertRecord(), we need to move
-  all record references. This is table->getInsertRecord() itself and
-  the field pointers of the fields used in this key.
-  */
-  if (ptrdiff)
-  {
-    save_record_0= getTable()->getInsertRecord();
-    getTable()->record[0]= buf;
-    key_info= getTable()->key_info + active_index;
-    key_part= key_info->key_part;
-    key_part_end= key_part + key_info->key_parts;
-    for (; key_part < key_part_end; key_part++)
-    {
-      assert(key_part->field);
-      key_part->field->move_field_offset(ptrdiff);
-    }
-  }
-
-  if (key_cmp_if_same(getTable(), key, active_index, keylen))
-  {
-    getTable()->status=STATUS_NOT_FOUND;
-    error= HA_ERR_END_OF_FILE;
-  }
-
-  /* Move back if necessary. */
-  if (ptrdiff)
-  {
-    getTable()->record[0]= save_record_0;
-    for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
-      key_part->field->move_field_offset(-ptrdiff);
+  int error;
+  if (!(error=index_next(buf)))
+  {
+    ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
+    unsigned char *save_record_0= NULL;
+    KeyInfo *key_info= NULL;
+    KeyPartInfo *key_part;
+    KeyPartInfo *key_part_end= NULL;
+
+    /*
+      key_cmp_if_same() compares table->getInsertRecord() against 'key'.
+      In parts it uses table->getInsertRecord() directly, in parts it uses
+      field objects with their local pointers into table->getInsertRecord().
+      If 'buf' is distinct from table->getInsertRecord(), we need to move
+      all record references. This is table->getInsertRecord() itself and
+      the field pointers of the fields used in this key.
+    */
+    if (ptrdiff)
+    {
+      save_record_0= getTable()->getInsertRecord();
+      getTable()->record[0]= buf;
+      key_info= getTable()->key_info + active_index;
+      key_part= key_info->key_part;
+      key_part_end= key_part + key_info->key_parts;
+      for (; key_part < key_part_end; key_part++)
+      {
+        assert(key_part->field);
+        key_part->field->move_field_offset(ptrdiff);
+      }
+    }
+
+    if (key_cmp_if_same(getTable(), key, active_index, keylen))
+    {
+      getTable()->status=STATUS_NOT_FOUND;
+      error=HA_ERR_END_OF_FILE;
+    }
+
+    /* Move back if necessary. */
+    if (ptrdiff)
+    {
+      getTable()->record[0]= save_record_0;
+      for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
+        key_part->field->move_field_offset(-ptrdiff);
+    }
   }
   return error;
 }

=== modified file 'drizzled/cursor.h'
--- drizzled/cursor.h	2011-08-08 12:51:19 +0000
+++ drizzled/cursor.h	2011-06-23 10:02:30 +0000
@@ -170,7 +170,7 @@
     get_auto_increment().
   */
   uint64_t next_insert_id;
-  uint64_t getNextInsertId() const
+  uint64_t getNextInsertId()
   {
     return next_insert_id;
   }
@@ -178,7 +178,7 @@
   /**
     Used by SHOW TABLE STATUS to get the current auto_inc from the engine
   */
-  uint64_t getAutoIncrement() const
+  uint64_t getAutoIncrement()
   {
     return stats.auto_increment_value;
   }
@@ -223,7 +223,10 @@
   int updateRecord(const unsigned char * old_data, unsigned char * new_data) __attribute__ ((warn_unused_result));
   int deleteRecord(const unsigned char * buf) __attribute__ ((warn_unused_result));
   void ha_release_auto_increment();
+
+  /** to be actually called to get 'check()' functionality*/
   int ha_check(Session*);
+
   void ha_start_bulk_insert(ha_rows rows);
   int ha_end_bulk_insert();
   int ha_delete_all_rows();
@@ -233,7 +236,7 @@
   int ha_disable_indexes(uint32_t mode);
   int ha_enable_indexes(uint32_t mode);
   int ha_discard_or_import_tablespace(bool discard);
-  void closeMarkForDelete();
+  void closeMarkForDelete(const char *name);
 
   void adjust_next_insert_id_after_explicit_value(uint64_t nr);
   int update_auto_increment();
@@ -600,7 +603,7 @@
     no new engine should ever use it). Right
     now HEAP does rely on it, so we cannot remove it.
   */
-  virtual void drop_table();
+  virtual void drop_table(const char *name);
 };
 
 extern const char *ha_row_type[];

=== modified file 'drizzled/field/blob.h'
--- drizzled/field/blob.h	2011-08-08 13:26:46 +0000
+++ drizzled/field/blob.h	2011-06-20 15:04:56 +0000
@@ -157,18 +157,23 @@
   void set_key_image(const unsigned char *buff,uint32_t length);
   inline void copy()
   {
-    value.copy((char*)get_ptr(), get_length(), charset());
-    char* tmp= value.ptr();
-    memcpy(ptr + sizeof(uint32_t), &tmp, sizeof(char*));
+    unsigned char* tmp= get_ptr();
+    value.copy((char*) tmp, get_length(), charset());
+    tmp=(unsigned char*) value.ptr();
+    memcpy(ptr+sizeof(uint32_t),&tmp,sizeof(char*));
   }
-  virtual unsigned char *pack(unsigned char *to, const unsigned char *from, uint32_t max_length, bool low_byte_first);
-  unsigned char *pack_key(unsigned char *to, const unsigned char *from, uint32_t max_length, bool low_byte_first);
-  virtual const unsigned char *unpack(unsigned char *to, const unsigned char *from, uint32_t , bool low_byte_first);
+  virtual unsigned char *pack(unsigned char *to, const unsigned char *from,
+                      uint32_t max_length, bool low_byte_first);
+  unsigned char *pack_key(unsigned char *to, const unsigned char *from,
+                  uint32_t max_length, bool low_byte_first);
+  virtual const unsigned char *unpack(unsigned char *to, const unsigned char *from,
+                              uint32_t , bool low_byte_first);
   void free() { value.free(); }
+  inline void clear_temporary() { memset(&value, 0, sizeof(value)); }
   friend int field_conv(Field *to,Field *from);
   uint32_t size_of() const { return sizeof(*this); }
   bool has_charset(void) const
-  { return charset() != &my_charset_bin; }
+  { return charset() == &my_charset_bin ? false : true; }
   uint32_t max_display_length();
 };
 

=== modified file 'drizzled/function/find_in_set.cc'
--- drizzled/function/find_in_set.cc	2011-08-08 12:51:19 +0000
+++ drizzled/function/find_in_set.cc	2011-04-20 22:18:30 +0000
@@ -61,7 +61,8 @@
   }
   null_value=0;
 
-  if (buffer->length() >= find->length())  
+  int diff;
+  if ((diff=buffer->length() - find->length()) >= 0)
   {
     my_wc_t wc;
     const charset_info_st * const cs= cmp_collation.collation;
@@ -74,7 +75,8 @@
     while (1)
     {
       int symbol_len;
-      if ((symbol_len= cs->cset->mb_wc(cs, &wc, (unsigned char*) str_end, (unsigned char*) real_end)) > 0)
+      if ((symbol_len= cs->cset->mb_wc(cs, &wc, (unsigned char*) str_end,
+                                       (unsigned char*) real_end)) > 0)
       {
         const char *substr_end= str_end + symbol_len;
         bool is_last_item= (substr_end == real_end);
@@ -98,7 +100,7 @@
                wc == (my_wc_t) separator)
         return (int64_t) ++position;
       else
-        return 0;
+        return 0L;
     }
   }
   return 0;

=== modified file 'drizzled/generator/all_foreign_keys.h'
--- drizzled/generator/all_foreign_keys.h	2011-08-08 12:51:19 +0000
+++ drizzled/generator/all_foreign_keys.h	2011-03-14 05:40:28 +0000
@@ -49,7 +49,8 @@
       do {
         if (foreign_keys_iterator != table_message.fk_constraint_size())
         {
-          return &table_message.fk_constraint(foreign_keys_iterator++);
+          const message::Table::ForeignKeyConstraint &fk_constraint(table_message.fk_constraint(foreign_keys_iterator++));
+          return &fk_constraint;
         }
 
       } while ((table_ptr= all_tables_generator) && table_setup());
@@ -70,7 +71,8 @@
       } while ((table_ptr= all_tables_generator) && table_setup());
     }
 
-    return ForeignKeyConstraintPair();
+    ForeignKeyConstraintPair null_pair;
+    return null_pair;
   }
 };
 

=== modified file 'drizzled/internal/my_symlink2.cc'
--- drizzled/internal/my_symlink2.cc	2011-08-08 12:51:19 +0000
+++ drizzled/internal/my_symlink2.cc	2011-06-24 15:25:06 +0000
@@ -26,30 +26,38 @@
 #include <drizzled/error.h>
 #include <drizzled/internal/m_string.h>
 
-namespace drizzled {
-namespace internal {
+namespace drizzled
+{
+namespace internal
+{
 
 int my_create_with_symlink(const char *linkname, const char *filename,
                            int createflags, int access_flags, myf MyFlags)
 {
+  int file;
+  int tmp_errno;
   /* Test if we should create a link */
-  bool create_link= false;
+  int create_link;
+  char abs_linkname[FN_REFLEN];
   char rp_buff[PATH_MAX];
 
   if (my_disable_symlinks)
   {
     /* Create only the file, not the link and file */
+    create_link= 0;
     if (linkname)
       filename= linkname;
   }
-  else if (linkname)
+  else
   {
-    if (!realpath(linkname,rp_buff))
-      my_load_path(rp_buff, linkname, NULL);
-    rp_buff[FN_REFLEN-1]= '\0';
-    char abs_linkname[FN_REFLEN];
-    strcpy(abs_linkname, rp_buff);
-    create_link= strcmp(abs_linkname, filename);
+    if (linkname)
+    {
+      if (!realpath(linkname,rp_buff))
+        my_load_path(rp_buff, linkname, NULL);
+      rp_buff[FN_REFLEN-1]= '\0';
+      strcpy(abs_linkname,rp_buff);
+    }
+    create_link= (linkname && strcmp(abs_linkname,filename));
   }
 
   if (!(MyFlags & MY_DELETE_OLD))
@@ -68,26 +76,28 @@
     }
   }
 
-  int file= my_create(filename, createflags, access_flags, MyFlags);
-  if (file >= 0 && create_link)
+  if ((file=my_create(filename, createflags, access_flags, MyFlags)) >= 0)
   {
-    /* Delete old link/file */
-    if (MyFlags & MY_DELETE_OLD)
-      my_delete(linkname, MYF(0));
-    /* Create link */
-    if (symlink(filename,linkname))
+    if (create_link)
     {
-      /* Fail, remove everything we have done */
-      int tmp_errno= errno;
-      my_close(file, MYF(0));
-      my_delete(filename, MYF(0));
-      file= -1;
-      errno= tmp_errno;
+      /* Delete old link/file */
+      if (MyFlags & MY_DELETE_OLD)
+	my_delete(linkname, MYF(0));
+      /* Create link */
+      if (symlink(filename,linkname))
+      {
+	/* Fail, remove everything we have done */
+	tmp_errno=errno;
+	my_close(file,MYF(0));
+	my_delete(filename, MYF(0));
+	file= -1;
+	errno=tmp_errno;
+      }
+      else if (MyFlags & MY_SYNC_DIR)
+        my_sync_dir_by_file(linkname, MyFlags);
     }
-    else if (MyFlags & MY_SYNC_DIR)
-      my_sync_dir_by_file(linkname, MyFlags);
   }
-  return file;
+  return(file);
 }
 
 /*

=== modified file 'drizzled/lex_input_stream.h'
--- drizzled/lex_input_stream.h	2011-08-08 12:51:19 +0000
+++ drizzled/lex_input_stream.h	2011-08-03 10:04:55 +0000
@@ -145,9 +145,9 @@
     End of file indicator for the query text to parse.
     @return true if there are no more characters to parse
   */
-  bool eof() const
+  bool eof()
   {
-    return m_ptr >= m_end_of_query;
+    return (m_ptr >= m_end_of_query);
   }
 
   /**
@@ -155,25 +155,25 @@
     @param n number of characters expected
     @return true if there are less than n characters to parse
   */
-  bool eof(int n) const
+  bool eof(int n)
   {
-    return m_ptr + n >= m_end_of_query;
+    return ((m_ptr + n) >= m_end_of_query);
   }
 
   /** Get the raw query buffer. */
-  const char *get_buf() const
+  const char *get_buf()
   {
     return m_buf;
   }
 
   /** Get the pre-processed query buffer. */
-  const char *get_cpp_buf() const
+  const char *get_cpp_buf()
   {
     return m_cpp_buf;
   }
 
   /** Get the end of the raw query buffer. */
-  const char *get_end_of_query() const
+  const char *get_end_of_query()
   {
     return m_end_of_query;
   }

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-08-08 15:51:23 +0000
+++ drizzled/session.cc	2011-08-05 12:55:59 +0000
@@ -861,12 +861,21 @@
                               instead of using lex_str value
   @return  NULL on failure, or pointer to the lex_string_t object
 */
-lex_string_t* Session::make_lex_string(lex_string_t* lex_str, str_ref str)
-{
-  if (not lex_str)
+lex_string_t *Session::make_lex_string(lex_string_t *lex_str,
+                                     const std::string &str,
+                                     bool allocate_lex_string)
+{
+  return make_lex_string(lex_str, str.c_str(), str.length(), allocate_lex_string);
+}
+
+lex_string_t *Session::make_lex_string(lex_string_t *lex_str,
+                                     const char* str, uint32_t length,
+                                     bool allocate_lex_string)
+{
+  if (allocate_lex_string)
     lex_str= new (mem) lex_string_t;
-  lex_str->str= mem_root->strdup(str);
-  lex_str->length= str.size();
+  lex_str->str= mem_root->strdup(str, length);
+  lex_str->length= length;
   return lex_str;
 }
 
@@ -885,11 +894,18 @@
   item->maybe_null=1;
   field_list.push_back(item= new Item_empty_string("key", NAME_CHAR_LEN, cs));
   item->maybe_null=1;
-  field_list.push_back(item= new Item_empty_string("key_len", MAX_KEY * (MAX_KEY_LENGTH_DECIMAL_WIDTH + 1 /* for comma */), cs));
-  item->maybe_null=1;
-  field_list.push_back(item= new Item_empty_string("ref", NAME_CHAR_LEN*MAX_REF_PARTS, cs));
-  item->maybe_null=1;
-  field_list.push_back(item= new Item_return_int("rows", 10, DRIZZLE_TYPE_LONGLONG));
+  field_list.push_back(item=
+    new Item_empty_string("key_len",
+                          MAX_KEY *
+                          (MAX_KEY_LENGTH_DECIMAL_WIDTH + 1 /* for comma */),
+                          cs));
+  item->maybe_null=1;
+  field_list.push_back(item=new Item_empty_string("ref",
+                                                  NAME_CHAR_LEN*MAX_REF_PARTS,
+                                                  cs));
+  item->maybe_null=1;
+  field_list.push_back(item= new Item_return_int("rows", 10,
+                                                 DRIZZLE_TYPE_LONGLONG));
   if (lex().describe & DESCRIBE_EXTENDED)
   {
     field_list.push_back(item= new Item_float("filtered", 0.1234, 2, 4));

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-08-08 15:51:23 +0000
+++ drizzled/session.h	2011-08-08 09:51:16 +0000
@@ -826,7 +826,13 @@
     return server_status & SERVER_STATUS_IN_TRANS;
   }
 
-  lex_string_t* make_lex_string(lex_string_t*, str_ref);
+  lex_string_t *make_lex_string(lex_string_t *lex_str,
+                              const char* str, uint32_t length,
+                              bool allocate_lex_string);
+
+  lex_string_t *make_lex_string(lex_string_t *lex_str,
+                              const std::string &str,
+                              bool allocate_lex_string);
 
   void send_explain_fields(select_result*);
 

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-08-08 15:51:23 +0000
+++ drizzled/sql_parse.cc	2011-08-05 13:28:48 +0000
@@ -409,8 +409,8 @@
      We have to make non const db_name & table_name
      because of lower_case_table_names
   */
-  session.make_lex_string(&db, str_ref("data_dictionary"));
-  session.make_lex_string(&table, schema_table_name);
+  session.make_lex_string(&db, "data_dictionary", sizeof("data_dictionary"), false);
+  session.make_lex_string(&table, schema_table_name, false);
   return not sel.add_table_to_list(&session, new Table_ident(db, table), NULL, table_options, TL_READ);
 }
 

=== modified file 'drizzled/sql_string.cc'
--- drizzled/sql_string.cc	2011-08-08 13:26:46 +0000
+++ drizzled/sql_string.cc	2011-08-05 10:58:50 +0000
@@ -184,14 +184,16 @@
   str_length=str.str_length;
   memmove(Ptr, str.Ptr, str_length);		// May be overlapping
   Ptr[str_length]=0;
-  str_charset= str.str_charset;
+  str_charset=str.str_charset;
 }
 
-void String::copy(const std::string& arg, const charset_info_st* cs) // Allocate new string
+void String::copy(const std::string& arg, const charset_info_st * const cs)	// Allocate new string
 {
   alloc(arg.size());
-  str_length= arg.size();
-  memcpy(Ptr, arg.c_str(), arg.size());
+
+  if ((str_length= arg.size()))
+    memcpy(Ptr, arg.c_str(), arg.size());
+
   Ptr[arg.size()]= 0;
   str_charset= cs;
 }
@@ -313,17 +315,19 @@
   append(s, arg_length);
 }
 
-size_t String::numchars() const
+size_t String::numchars()
 {
   return str_charset->cset->numchars(str_charset, Ptr, Ptr+str_length);
 }
 
-int String::charpos(int i,size_t offset) const
+int String::charpos(int i,size_t offset)
 {
-  return i <= 0 ? i : str_charset->cset->charpos(str_charset, Ptr + offset, Ptr + str_length, i);
+  if (i <= 0)
+    return i;
+  return str_charset->cset->charpos(str_charset,Ptr+offset,Ptr+str_length,i);
 }
 
-int String::strstr(const String &s, size_t offset)
+int String::strstr(const String &s,size_t offset)
 {
   if (s.length() + offset <= str_length)
   {

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2011-08-08 13:26:46 +0000
+++ drizzled/sql_string.h	2011-08-05 10:58:50 +0000
@@ -275,8 +275,8 @@
   friend int sortcmp(const String *a,const String *b, const charset_info_st * const cs);
   friend int stringcmp(const String *a,const String *b);
   friend String *copy_if_not_alloced(String *a,String *b,size_t arg_length);
-  size_t numchars() const;
-  int charpos(int i, size_t offset= 0) const;
+  size_t numchars();
+  int charpos(int i,size_t offset=0);
 
   void reserve(size_t space_needed)
   {

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-08-08 12:51:19 +0000
+++ drizzled/sql_table.cc	2011-07-07 13:41:07 +0000
@@ -2137,13 +2137,16 @@
 
 bool analyze_table(Session* session, TableList* tables)
 {
-  return admin_table(session, tables, "analyze", TL_READ_NO_INSERT, true, &Cursor::ha_analyze);
+  thr_lock_type lock_type = TL_READ_NO_INSERT;
+
+  return(admin_table(session, tables, "analyze", lock_type, true, &Cursor::ha_analyze));
 }
 
 
 bool check_table(Session* session, TableList* tables)
 {
-  return admin_table(session, tables, "check", TL_READ_NO_INSERT, false, &Cursor::ha_check);
+  thr_lock_type lock_type = TL_READ_NO_INSERT;
+  return admin_table(session, tables, "check", lock_type, false, &Cursor::ha_check);
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/statement/alter_schema.cc'
--- drizzled/statement/alter_schema.cc	2011-08-08 12:51:19 +0000
+++ drizzled/statement/alter_schema.cc	2011-07-25 14:24:19 +0000
@@ -84,7 +84,9 @@
   
   drizzled::message::update(schema_message);
 
-  return not schema::alter(session(), schema_message, *old_definition);
+  bool res= schema::alter(session(), schema_message, *old_definition);
+
+  return not res;
 }
 
 } /* namespace drizzled */

=== modified file 'drizzled/statement/check.cc'
--- drizzled/statement/check.cc	2011-08-08 13:26:46 +0000
+++ drizzled/statement/check.cc	2011-06-23 10:02:30 +0000
@@ -32,10 +32,12 @@
   TableList *first_table= (TableList *) lex().select_lex.table_list.first;
   TableList *all_tables= lex().query_tables;
   assert(first_table == all_tables && first_table != 0);
+  Select_Lex *select_lex= &lex().select_lex;
   bool res= check_table(&session(), first_table);
-  lex().select_lex.table_list.first= (unsigned char*) first_table;
+  select_lex->table_list.first= (unsigned char*) first_table;
   lex().query_tables=all_tables;
   return res;
 }
 
 } /* namespace drizzled */
+

=== modified file 'drizzled/table/singular.cc'
--- drizzled/table/singular.cc	2011-08-08 12:51:19 +0000
+++ drizzled/table/singular.cc	2011-07-05 14:36:13 +0000
@@ -126,8 +126,12 @@
 
 bool Singular::open_tmp_table()
 {
+  int error;
+  
   identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getPath());
-  if (int error= cursor->ha_open(identifier, O_RDWR, HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE))
+  if ((error=cursor->ha_open(identifier,
+                             O_RDWR,
+                             HA_OPEN_TMP_TABLE | HA_OPEN_INTERNAL_TABLE)))
   {
     print_error(error, MYF(0));
     db_stat= 0;
@@ -299,11 +303,17 @@
   if (cursor)
   {
     if (db_stat)
-      cursor->closeMarkForDelete();
+    {
+      cursor->closeMarkForDelete(getShare()->getTableName());
+    }
 
     identifier::Table identifier(getShare()->getSchemaName(), getShare()->getTableName(), getShare()->getTableName());
     drizzled::error_t ignored;
-    plugin::StorageEngine::dropTable(*in_use, *getShare()->getEngine(), identifier, ignored);
+    plugin::StorageEngine::dropTable(*in_use,
+                                     *getShare()->getEngine(),
+                                     identifier,
+                                     ignored);
+
     delete cursor;
   }
 
@@ -318,5 +328,6 @@
   in_use->set_proc_info(save_proc_info);
 }
 
+
 } /* namespace table */
 } /* namespace drizzled */

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2011-08-08 15:51:23 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2011-08-07 22:41:28 +0000
@@ -7807,7 +7807,7 @@
     while (tmp_buff[i] != '/')
       i++;
     tmp_buff += i + 1;
-    lex_string_t *tmp_foreign_id = session->make_lex_string(NULL, str_ref(tmp_buff));
+    lex_string_t *tmp_foreign_id = session->make_lex_string(NULL, tmp_buff, strlen(tmp_buff), true);
 
     /* Database name */
     tmp_buff = foreign->referenced_table_name;
@@ -7820,23 +7820,22 @@
     }
     db_name[i] = 0;
     ulen= identifier::Table::filename_to_tablename(db_name, uname, sizeof(uname));
-    lex_string_t *tmp_referenced_db = session->make_lex_string(NULL, str_ref(uname, ulen));
+    lex_string_t *tmp_referenced_db = session->make_lex_string(NULL, uname, ulen, true);
 
     /* Table name */
     tmp_buff += i + 1;
     ulen= identifier::Table::filename_to_tablename(tmp_buff, uname, sizeof(uname));
-    lex_string_t *tmp_referenced_table = session->make_lex_string(NULL, str_ref(uname, ulen));
+    lex_string_t *tmp_referenced_table = session->make_lex_string(NULL, uname, ulen, true);
 
     /** Foreign Fields **/
     List<lex_string_t> tmp_foreign_fields;
     List<lex_string_t> tmp_referenced_fields;
-    for (i= 0;;) 
-		{
+    for (i= 0;;) {
       tmp_buff= foreign->foreign_col_names[i];
-      name = session->make_lex_string(NULL, str_ref(tmp_buff));
+      name = session->make_lex_string(name, tmp_buff, strlen(tmp_buff), true);
       tmp_foreign_fields.push_back(name);
       tmp_buff= foreign->referenced_col_names[i];
-      name = session->make_lex_string(NULL, str_ref(tmp_buff));
+      name = session->make_lex_string(name, tmp_buff, strlen(tmp_buff), true);
       tmp_referenced_fields.push_back(name);
       if (++i >= foreign->n_fields)
         break;
@@ -7863,7 +7862,7 @@
       length=8;
       tmp_buff= "RESTRICT";
     }
-    lex_string_t *tmp_delete_method = session->make_lex_string(NULL, str_ref(tmp_buff, length));
+    lex_string_t *tmp_delete_method = session->make_lex_string(NULL, tmp_buff, length, true);
 
 
     if (foreign->type & DICT_FOREIGN_ON_UPDATE_CASCADE)
@@ -7886,14 +7885,15 @@
       length=8;
       tmp_buff= "RESTRICT";
     }
-    lex_string_t *tmp_update_method = session->make_lex_string(NULL, str_ref(tmp_buff, length));
+    lex_string_t *tmp_update_method = session->make_lex_string(NULL, tmp_buff, length, true);
 
     lex_string_t *tmp_referenced_key_name = NULL;
 
     if (foreign->referenced_index &&
         foreign->referenced_index->name)
     {
-      tmp_referenced_key_name = session->make_lex_string(NULL, str_ref(foreign->referenced_index->name));
+      tmp_referenced_key_name = session->make_lex_string(NULL,
+                                                         foreign->referenced_index->name, strlen(foreign->referenced_index->name), true);
     }
 
     ForeignKeyInfo f_key_info(

=== modified file 'plugin/memory/ha_heap.cc'
--- plugin/memory/ha_heap.cc	2011-08-08 12:51:19 +0000
+++ plugin/memory/ha_heap.cc	2011-07-15 08:26:31 +0000
@@ -621,12 +621,12 @@
    [2  non-unique indexes are disabled - NOT YET IMPLEMENTED]
 */
 
-int ha_heap::indexes_are_disabled()
+int ha_heap::indexes_are_disabled(void)
 {
   return heap_indexes_are_disabled(file);
 }
 
-void ha_heap::drop_table()
+void ha_heap::drop_table(const char *)
 {
   file->getShare()->delete_on_close= 1;
   close();

=== modified file 'plugin/memory/ha_heap.h'
--- plugin/memory/ha_heap.h	2011-08-08 12:51:19 +0000
+++ plugin/memory/ha_heap.h	2011-03-14 05:40:28 +0000
@@ -83,7 +83,7 @@
   drizzled::ha_rows records_in_range(uint32_t inx,
                                      drizzled::key_range *min_key,
                                      drizzled::key_range *max_key);
-  void drop_table();
+  void drop_table(const char *name);
 
   int cmp_ref(const unsigned char *ref1, const unsigned char *ref2);
   int reset_auto_increment(uint64_t value)

